parse

Function parse 

pub fn parse(header_value: &str) -> UnsubscribeMethod
Parse a raw List-Unsubscribe header value into an UnsubscribeMethod.

Equivalent to parse_with_post with post_header_value = None. Use this when you have not been able to retrieve List-Unsubscribe-Post — for example because the message store discarded it. RFC 8058 one-click detection requires both headers, so this entry point will never return UnsubscribeMethod::OneClick.